package io.renren.modules.admin.meeting.controller;

import java.util.Arrays;
import java.util.Map;
import java.util.Date;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.renren.modules.admin.meeting.entity.MeetingEntity;
import io.renren.modules.admin.meeting.service.MeetingService;
import io.renren.common.utils.PageUtils;
import io.renren.common.utils.R;



/**
 * 会议表
 *
 * @author chenshun
 * @email sunlightcs@gmail.com
 * @date 2020-02-20 14:59:39
 */
@RestController
@RequestMapping("admin/meeting")
public class MeetingController {
    @Autowired
    private MeetingService meetingService;

    /**
     * 列表
     */
    @RequestMapping("/list")
    @RequiresPermissions("admin:meeting:list")
    public R list(@RequestParam Map<String, Object> params){
        PageUtils page = meetingService.queryPage(params);

        return R.ok().put("page", page);
    }


    /**
     * 信息
     */
    @RequestMapping("/info/{id}")
    @RequiresPermissions("admin:meeting:info")
    public R info(@PathVariable("id") Long id){
		MeetingEntity meeting = meetingService.getById(id);

        return R.ok().put("meeting", meeting);
    }

    /**
     * 保存
     */
    @RequestMapping("/save")
    @RequiresPermissions("admin:meeting:save")
    public R save(@RequestBody MeetingEntity meeting){
        meeting.setCreateTime(new Date());
		meetingService.save(meeting);

        return R.ok();
    }

    /**
     * 修改
     */
    @RequestMapping("/update")
    @RequiresPermissions("admin:meeting:update")
    public R update(@RequestBody MeetingEntity meeting){
        meeting.setModifyTime(new Date());
		meetingService.updateById(meeting);

        return R.ok();
    }

    /**
     * 删除
     */
    // @RequestMapping("/delete")
    // @RequiresPermissions("admin:meeting:delete")
    // public R delete(@RequestBody Long[] ids){
	// 	meetingService.removeByIds(Arrays.asList(ids));

    //     return R.ok();
    // }
    @PostMapping("/delete")
    @RequiresPermissions("admin:meeting:delete")
    public R delete(@RequestBody Long[] ids){
        meetingService.delete(ids);
        return R.ok();
    }

    @PostMapping("/status")
    @RequiresPermissions("admin:meeting:status")
    public R status(@RequestBody Map<String, Object> param){
        Long id = Long.valueOf(param.get("id").toString());
        Integer status = Integer.valueOf(param.get("status").toString());

        meetingService.updateStatus(id, status);
        return R.ok();
    }
}
